==> gpfs-2.3.0-24.x86_64.update.tar.gz: usr/lpp/mmfs/src/ibm-linux/cxiMmap-plat.h <==
/***************************************************************************
 *
 * Copyright (C) 2001 International Business Machines
 * All rights reserved.
 *
 * This file is part of the GPFS mmfslinux kernel module.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer. 
 *  2. Redistributions in binary form must reproduce the above copyright 
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution. 
 *  3. The name of the author may not be used to endorse or promote products 
 *     derived from this software without specific prior written
 *     permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *************************************************************************** */
/* @(#)02       1.22  src/avs/fs/mmfs/ts/kernext/ibm-linux/cxiMmap-plat.h, mmfs, avs_rcs3b, rcs3bs004a 6/2/03 13:01:17 */
/*
 * Platform specific definitions for memory mapped files, Linux version
 *
 */

#ifndef _h_cxiMmap_plat
#define _h_cxiMmap_plat

#ifndef _h_cxiMmap
#error Platform header (XXX-plat.h) should not be included directly
#endif

#include <cxiTypes.h>

#ifdef __cplusplus
extern "C"
{
#endif /*__cplusplus */
Int64 getFilePos(cxibuf_t *bufP);
char *VM_Attach(cxibuf_t *bufP);
void VM_Detach(cxibuf_t *bufP, char *baddrP);
void getVp(void * gnP,void **vP, struct gpfsVfsData_t **privVfsP);
void IoDone(cxibuf_t *bufP);
void mmapKill();
void EnableMmap();
#define mmStrategy NULL
int cxiMmapRegister(void *dummy);
int cxiMmapUnregister(void *dummy);
int cxiMmapFlush(cxiNode_t *cnP, UInt64 start, UInt64 end,
                 enum CmflushOption cmopt);
int cxiMmapGetPage(cxibuf_t *bufP);
void cxiMmapReleasePage(struct page *pageP);
#ifdef __cplusplus
}
#endif /*__cplusplus */

#endif  /* _h_cxiMmap_plat */

==> gpfs-3.2.1-6.x86_64.update.tar.gz: usr/lpp/mmfs/src/ibm-linux/cxiMmap-plat.h <==
/***************************************************************************
 *
 * Copyright (C) 2001 International Business Machines
 * All rights reserved.
 *
 * This file is part of the GPFS mmfslinux kernel module.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions 
 * are met:
 *
 *  1. Redistributions of source code must retain the above copyright notice, 
 *     this list of conditions and the following disclaimer. 
 *  2. Redistributions in binary form must reproduce the above copyright 
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution. 
 *  3. The name of the author may not be used to endorse or promote products 
 *     derived from this software without specific prior written
 *     permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR 
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF 
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *************************************************************************** */
/* @(#)02       1.23  src/avs/fs/mmfs/ts/kernext/ibm-linux/cxiMmap-plat.h, mmfs, avs_rgpfs32, rgpfs32s001a 7/16/07 02:44:25 */
/*
 * Platform specific definitions for memory mapped files, Linux version
 *
 */

#ifndef _h_cxiMmap_plat
#define _h_cxiMmap_plat

#ifndef _h_cxiMmap
#error Platform header (XXX-plat.h) should not be included directly
#endif

#include <cxiTypes.h>

#ifdef __cplusplus
extern "C"
{
#endif /*__cplusplus */
Int64 getFilePos(cxibuf_t *bufP);
char *VM_Attach(cxibuf_t *bufP);
void VM_Detach(cxibuf_t *bufP, char *baddrP);
void getVp(void * gnP,void **vP, struct gpfsVfsData_t **privVfsP);
void IoDone(cxibuf_t *bufP);
void mmapKill();
void EnableMmap();
#define mmStrategy NULL
IntRC cxiMmapRegister(void *dummy);
IntRC cxiMmapUnregister(void *dummy);
IntRC cxiMmapFlush(cxiNode_t *cnP, UInt64 start, UInt64 end,
                   enum CmflushOption cmopt);
IntRC cxiMmapGetPage(cxibuf_t *bufP);
void cxiMmapReleasePage(struct page *pageP);
#ifdef __cplusplus
}
#endif /*__cplusplus */

#endif  /* _h_cxiMmap_plat */
